==> FHLBBS-4.2.tgz: wbbs/delete.c <==
#include "cgic.h"
#include "wbbs.c"

FILE *fptr1,*fptr2;
char buf1[200];

int cgiMain() {
   char *foo, path1[100], curr_board[100], oneline[300],buf2[100],buf[100],chk[5];
   time_t t1;
   int len1, fd, numposts, i,j, numarticle, filecount, fd1,delcnt;
   int readmode; //readmode=0 Qװ readmode=1 mail
   struct fileheader readfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   char *bdname;

   strncpy(curr_board, getenv("QUERY_STRING"),99);
   curr_board[99]=0;
   if(!check_passwd())
      return(0);
   if (strrchr(curr_board,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }   
   bdname=curr_board;

   if (!strcmp(curr_board,"mail"))
      readmode=1;
   else
      readmode=0;

   bp = getbcache(bdname);
 
   if(((!bp)||(!Ben_Perm(bp)))&&(!readmode)){
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
      return(0);
   }

   //cgiHeaderContentType("text/html");

   /***** IF ɮתv ****/
   //fprintf(cgiOut,"%s<p>\n",curr_board);
   sprintf(path1,BBSHOME "/home/%s/.DIR", cuser.userid);
   //fprintf(cgiOut,"%s<p>\n",path1);
   for(i=1;i<SHOWNUM+1;i++){
      sprintf(buf,"m%d", i);
      cgiFormStringNoNewlines(buf,chk,5); 
      sprintf(buf,"%d chk=%s||",i,chk);
      //fprintf(cgiOut,"%s<p>\n",buf);
      if(chk[0]!=0x00){
         sscanf(chk,"%d",&delcnt);
         delete_record(path1, sizeof(fileheader), delcnt);
      }
   }
   //fprintf(cgiOut," Delete mail successful.\n");
   cgiHeaderLocation("mlist.cgi");

   //fprintf(cgiOut,"<hr>\n");
   //fprintf(cgiOut,"</body></html>\n");
   return 0;
}

==> FHLBBS-5.3.tgz: wbbs/delete.c <==
#include "cgic.h"
#include "wbbs.c"

FILE *fptr1,*fptr2;
char buf1[200];

int cgiMain() {
   char *foo, path1[100], curr_board[100], oneline[300],buf2[100],buf[100],chk[5];
   time_t t1;
   int len1, fd, numposts, i,j, numarticle, filecount, fd1,delcnt;
   int readmode; //readmode=0 Qװ readmode=1 mail
   struct fileheader readfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   char *bdname;

   strncpy(curr_board, getenv("QUERY_STRING"),99);
   curr_board[99]=0;
   if(!check_passwd())
      return(0);
   if (strrchr(curr_board,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }   
   bdname=curr_board;

   if (!strcmp(curr_board,"mail"))
      readmode=1;
   else
      readmode=0;

   bp = getbcache(bdname);
 
   if(((!bp)||(!Ben_Perm(bp)))&&(!readmode)){
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"S %s oӰQװϡI<p>\n", bdname);
      return(0);
   }

   //cgiHeaderContentType("text/html");

   /***** IF ɮתv ****/
   //fprintf(cgiOut,"%s<p>\n",curr_board);
   sprintf(path1,BBSHOME "/home/%s/.DIR", cuser.userid);
   //fprintf(cgiOut,"%s<p>\n",path1);
   //for(i=1;i<SHOWNUM+1;i++){
    /****ѤUWAo.DIRǤ~| ******/
   for(i=SHOWNUM;i>0;i--){
      sprintf(buf,"m%d", i);
      cgiFormStringNoNewlines(buf,chk,5); 
      if(chk[0]!=0x00){
         sscanf(chk,"%d",&delcnt);
      	 //sprintf(buf,"%s %d chk=%s delcnt=%d||",buf,i,chk,delcnt);
         //fprintf(cgiOut,"%s<p>\n",buf);
         delete_record(path1, sizeof(fileheader), delcnt);
      }
   }
   //fprintf(cgiOut," Delete mail successful.\n");
   cgiHeaderLocation("mlist.cgi");

   //fprintf(cgiOut,"<hr>\n");
   //fprintf(cgiOut,"</body></html>\n");
   return 0;
}
